import React from 'react';
import { Bot, ArrowRight, Sparkles, ChevronDown, BrainCircuit } from 'lucide-react';

const Hero: React.FC = () => {
  const scrollToServices = () => {
    document.getElementById('services')?.scrollIntoView({ behavior: 'smooth' });
  };

  return (
    <div 
      className="relative min-h-screen pt-32 flex items-center overflow-hidden"
    >
      <div className="absolute inset-0">
        <div className="absolute inset-0 bg-gradient-to-b from-slate-950 via-slate-900 to-slate-950"></div>
        <div className="absolute inset-0 bg-grid-pattern opacity-5"></div>
        <div className="absolute inset-0">
          <div className="absolute top-0 left-1/4 w-[30rem] h-[30rem] bg-gradient-to-r from-sky-500/10 to-indigo-500/10 rounded-full filter blur-3xl"></div>
          <div className="absolute bottom-0 right-1/4 w-[30rem] h-[30rem] bg-gradient-to-r from-indigo-500/10 to-sky-500/10 rounded-full filter blur-3xl"></div>
        </div>
      </div>
      
      <div className="container mx-auto px-4 md:px-6 lg:px-8 relative z-10">
        <div className="max-w-4xl mx-auto text-center">
          <div className="relative inline-flex justify-center items-center mb-12 group">
            <div className="absolute inset-0 bg-gradient-to-r from-sky-500/20 to-indigo-500/20 rounded-full blur-xl group-hover:blur-2xl transition-all duration-500"></div>
            <div className="relative flex gap-4 bg-white/5 backdrop-blur p-8 rounded-2xl shadow-xl border border-white/10">
              <div className="relative w-24 h-24">
                <div className="absolute inset-0 bg-gradient-to-r from-sky-500/20 to-indigo-500/20 rounded-xl blur group-hover:blur-md transition-all duration-500"></div>
                <div className="absolute inset-0 bg-gradient-to-br from-sky-500 to-indigo-600 rounded-xl opacity-90"></div>
                <div className="absolute inset-0 flex items-center justify-center">
                  <div className="w-12 h-[2px] bg-white/25 rounded-full absolute transform translate-y-[9px]"></div>
                  <div className="w-12 h-[2px] bg-white/50 rounded-full absolute transform translate-y-[3px]"></div>
                  <div className="w-12 h-[2px] bg-white/75 rounded-full absolute transform translate-y-[-3px]"></div>
                  <div className="w-12 h-[2px] bg-white rounded-full absolute transform translate-y-[-9px]"></div>
                </div>
              </div>
              <div className="relative bg-gradient-to-br from-indigo-500 to-sky-600 p-6 rounded-xl transition-all duration-500">
                <div className="absolute inset-0 bg-gradient-to-r from-indigo-500/20 to-sky-500/20 rounded-xl blur group-hover:blur-xl transition-all duration-500"></div>
                <Bot className="h-10 w-10 text-white" />
              </div>
            </div>
          </div>
          
          <div className="inline-flex items-center gap-2 bg-white/5 backdrop-blur-sm border border-white/10 rounded-full px-6 py-2 text-sky-400 font-medium mb-8">
            <Sparkles className="h-5 w-5" />
            Mindful AI Communication
          </div>
          
          <h1 className="text-5xl md:text-6xl font-bold mb-8 leading-[1.1] tracking-tight">
            <div className="mb-2 text-white/90">Transform How</div>
            <div className="bg-gradient-to-r from-sky-400 via-indigo-400 to-sky-400 bg-clip-text text-transparent animate-gradient bg-300">
              Your Business Connects
            </div>
          </h1>
          
          <p className="text-lg md:text-xl text-slate-400 mb-12 leading-relaxed max-w-2xl mx-auto animate-fade-in">
            Experience the power of mindful AI communication that builds genuine connections, understands context, and responds with empathy.
          </p>
          
          <div className="flex flex-col sm:flex-row items-center justify-center gap-4">
            <a
              href="#contact"
              aria-label="Book your free strategy call"
              className="group relative inline-flex items-center px-8 py-4 text-base font-semibold text-white rounded-full overflow-hidden shadow-lg hover:shadow-xl transition-all duration-300"
            >
              <div className="absolute inset-0 bg-gradient-to-r from-sky-500 to-indigo-500 transition-all duration-300 group-hover:scale-105"></div>
              <div className="absolute inset-0 bg-[radial-gradient(circle_at_50%_50%,rgba(255,255,255,0.2),transparent_50%)] opacity-0 group-hover:opacity-100 transition-opacity duration-300"></div>
              <span className="relative">Book Your Free Strategy Call</span>
              <ArrowRight className="relative ml-2 h-5 w-5 transform group-hover:translate-x-1 transition-transform" />
            </a>
            
            <button
              onClick={scrollToServices}
              aria-label="Scroll to services section"
              className="group inline-flex items-center px-6 py-3 text-slate-400 hover:text-sky-400 transition-colors duration-300 bg-white/5 backdrop-blur-sm rounded-full border border-white/10 hover:border-sky-400/30"
            >
              Learn More
              <ChevronDown className="ml-1 h-5 w-5 animate-bounce" />
            </button>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Hero;